@@ -57,8 +57,6 @@ import Control.Exception        (bracket)
 
 -- getStdRandom has a bug, see safeGetStdRandom below.
 import System.Random hiding (split,random,getStdRandom)
-
-import System.IO
 import qualified System.Time as T
 
 ------------------------------------------------------------------------
@@ -375,7 +373,7 @@ parIO a1 a2 = do
   -- killThread blocks until the thread has been killed.  Therefore, we call
   -- killThread asynchronously in case one thread is blocked in a foreign
   -- call.
-  forkIO $ killThread c1 >> killThread c2
+  _ <- forkIO $ killThread c1 >> killThread c2
   return r
 
 -- | run an action with a timeout
